#include <stdio.h>

#include <libnotify/notify.h>
#include <libprelude/prelude-message-id.h>

#include "alert-callback.h"


static int
brouette_notify(const char *classification, const char *message)
{
        NotifyNotification *n;

	notify_init("Prelude");

        n = notify_notification_new (classification,
                                     message,
                                     NULL, NULL);
        notify_notification_set_timeout (n, 3000); //3 seconds

        if (!notify_notification_show (n, NULL)) {
	  fprintf(stderr, "failed to send notification\n");
	  return 1;
        }

        g_object_unref(G_OBJECT(n));

	return 0;
}

static const char *
brouette_get_classification(idmef_message_t *idmef_message)
{
        int ret;

        idmef_alert_t *alert;
	idmef_classification_t *classification;
	prelude_string_t *pstr;
	const char *buffer;


	alert = idmef_message_get_alert(idmef_message);
	if ( ! alert ) {
	        printf("Cannot get alert from message\n");
		return NULL;
	} 
	classification = idmef_alert_get_classification(alert);
	if ( ! classification ) {
	        printf("Cannot get classification from alert\n");
		return NULL;
	} 
	pstr = idmef_classification_get_text(classification);
	if ( ! pstr ) {
	        printf("Cannot get text from classification\n");
		return NULL;
	} 

	buffer = prelude_string_get_string(pstr);

	return buffer;

}

static const char *
brouette_get_assessment_description(idmef_message_t *idmef_message)
{

        int ret;

        idmef_alert_t *alert;
	idmef_assessment_t *assessment; 
	idmef_impact_t *impact; 
	prelude_string_t *pstr;
	const char *buffer;


	alert = idmef_message_get_alert(idmef_message);
	if ( ! alert ) {
	        printf("Cannot get alert from message\n");
		return NULL;
	} 
	assessment = idmef_alert_get_assessment(alert);
	if ( ! assessment ) {
	        printf("Cannot get assessment from alert\n");
		return NULL;
	} 
	impact = idmef_assessment_get_impact (assessment);
	if ( ! impact ) {
	        printf("Cannot get impact from assessment\n");
		return NULL;
	} 
	pstr = idmef_impact_get_description(impact);
	if ( ! impact ) {
	        printf("Cannot get description from impact\n");
		return NULL;
	} 

	buffer = prelude_string_get_string(pstr);
	
	return buffer;

}


extern int
process_idmef_message(prelude_msg_t *msg)
{
        int ret;
        idmef_message_t *idmef;
	const char *classbuf;
	const char *descrbuf;


        ret = idmef_message_new(&idmef);
        if ( ret < 0 )
                return ret;
        
        ret = idmef_message_read(idmef, msg);
        if ( ret < 0 ) {
                prelude_perror(ret, "error reading IDMEF message");
                return ret;
        }

	if ( idmef ) {
	  classbuf = brouette_get_classification(idmef);
	  descrbuf = brouette_get_assessment_description(idmef);

	  if ( ! classbuf ) classbuf="";
	  if ( ! descrbuf ) descrbuf="";

	  brouette_notify(classbuf, descrbuf);

	  idmef_message_destroy(idmef);
	}        

        return 0;
}


extern int event_cb(prelude_connection_pool_t *pool, prelude_connection_pool_event_t event, 
		    prelude_connection_t *conn, void *extra)
{
        int ret;
        prelude_msg_t *msg = NULL;


        ret = prelude_connection_recv(conn, &msg);
        if ( ret < 0 ) {
                prelude_perror(ret, "couldn't read message");
                return ret;
        }
        
        if ( prelude_msg_get_tag(msg) != PRELUDE_MSG_IDMEF )
                return 0;
                
        return process_idmef_message(msg);
}



