#include <stdio.h>

#include <libnotify/notify.h>

#include <libprelude/prelude.h>
#include <libprelude/prelude-message-id.h>
#include <libprelude/idmef-message-print.h>

#include "prelude.h"
#include "alert-callback.h"


static prelude_client_t *client;

extern int 
initialize_prelude(void)
{
        int ret;


        ret = prelude_init(NULL, NULL);
        if ( ret < 0 ) {
                prelude_perror(ret, "error initializing the prelude library");
                return ret;
        }

        ret = prelude_client_new(&client, "brouette");
        if ( ret < 0 ) {
                prelude_perror(ret, "error initializing prelude client");
                return ret;
        }

        prelude_client_set_required_permission(client, PRELUDE_CONNECTION_PERMISSION_IDMEF_READ);


        return 0;
}

extern int 
check_for_event(void* data)
{
        prelude_connection_pool_t *pool = data;
        int ret;

        ret = prelude_connection_pool_check_event(pool, 0, event_cb, NULL);
        if ( ret < 0 ) {
                prelude_perror(ret, "error setting callback");
                return -1;
        }

}

extern int 
connect_prelude(const char *manager_addr)
{
        int ret;
        prelude_connection_pool_t *pool;


        
        prelude_connection_pool_new(&pool, 
                                    prelude_client_get_profile(client), 
                                    prelude_client_get_required_permission(client));

        ret = prelude_connection_pool_set_connection_string(pool, manager_addr);
        if ( ret < 0 ) {
                prelude_perror(ret, "error setting new prelude connection string");
                return -1;
        }

	prelude_client_set_connection_pool(client, pool);

        ret = prelude_connection_pool_init(pool);
        if ( ret < 0 ) {
                prelude_perror(ret, "error initializing connection pool");
                return -1;
        }


        while (1) {
	        sleep(2);
                check_for_event(pool);
        }


	prelude_client_destroy(client, PRELUDE_CLIENT_EXIT_STATUS_SUCCESS);

        return 0;
}

int main(int argc, char **argv)
{

        int ret = 0;

	if ( argc <= 1 ) {
	  printf("Syntax: %s manager_address\n", argv[0]);
	        return 1;
	}
        
        ret = initialize_prelude();
        if ( ret < 0 ) {
                printf("Cannot initialize prelude\n");
        }

        connect_prelude(argv[1]);

        return 0;

}
